/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide( "com.ibm.mashups.enabler.Deferred");

//<INTERFACE>
/**
 * Base interface for all classes which handle actions asynchronously.
 * An action may involve one or more operations, for example creating or
 * updating a model resource, which in turn may involve one or more HTTP
 * requests. The Deferred interface allows to trigger a callback after
 * the entire action, i.e. all involved HTTP requests, is finished. Thus,
 * the Deferred interface may be used to get the overall result of an action.
 * @ibm-api
 * @ibm-module Base
 */
dojo.declare( "com.ibm.mashups.enabler.Deferred", null, {
	
    /**
     * Sets the handler of the deferred action. It is called when the entire
     * action has finished.<br> 
     * Please note that the status of the action is transported only with 
     * callbacks, even if you use synchronous mode. If you need to check the status, 
     * you must use callback functions.
     * @param {Object} callback the callback funtion in the format of <code>Function(Object resource, int statusCode, Object[] params)</code>. 
     * Must not be <code>null</code><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<b>Callbackparameters</b><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>resource</code> - resource object or id string
     * of the related resource.
     * May be <code>null</code> in case the action does not relate
     * to a particular resource. In case multiple resources are involved in the
     * action, the DeferredOperation interface may be used to obtain the resource
     * objects or string <code>id</code>s of those resources.<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>statusCode</code> - the overall HTTP status
     * code of the action (the highest status code of the involved operations).<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>params</code> - the parameters
     * passed into the callback
     * @param {Object[]} parameters optional array of parameters to be
     * passed on to the callback function. May be <code>null</code>
     * @return {com.ibm.mashups.enabler.Deferred} the deferred object
     */
    setFinishedCallback: function(callback, parameters) {
    },

    /**
     * Executes the deferred action and invokes the callback functions set
     * with the deferred object.
     * @param {Boolean} sync indicates if the deferred action is executed 
     * synchronously or asynchronously. Optional, defaults to true.
     * @return {Object} resource if called asynchronously, the return value is 
     * <code>undefined</code>, otherwise a resource object or id string of the 
     * related resource is returned.<br> In order to obtain information on
     * the resource as well as on the status code of the operation, you
     * must use the callback functions of the deferred object.
     */
    start: function(sync) {
        return {};
    }
});
//</INTERFACE>

dojo.require( "com.ibm.mm.enabler.DeferredImpl" );
