/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.DeferredOperation");

dojo.require("com.ibm.mashups.enabler.Deferred");
//<INTERFACE>
/**
 * In addition to the Deferred interface, which allows to trigger callbacks after the
 * entire action  has finished, the DeferredOperation interface allows to trigger a
 * callback for each involved operation.
 * @ibm-api
 * @ibm-module Base
 */
dojo.declare( "com.ibm.mashups.enabler.DeferredOperation", [com.ibm.mashups.enabler.Deferred], {

	/**
	 * Mode of operation: retrieving a resource 
	 * @type String
	 */
    OPERATION_GET: "GET",

	/**
	 * Mode of operation: creating a resource 
	 * @type String
	 */
    OPERATION_CREATE: "CREATE",

	/**
	 * Mode of operation: modifying a resource 
	 * @type String
	 */
    OPERATION_MODIFY: "MODIFY",

	/**
	 * Mode of operation: deleting a resource 
	 * @type String
	 */
    OPERATION_DELETE: "DELETE",


    /**
     * Sets the handler of the deferred action. The handler is called for each
     * operation the action involves.
     * @param {Object} callback the callback funtion in the format of <code>Function(Object node, string mode, int statusCode, Object[] params)</code>. Must not be <code>null</code><br/>
     * &nbsp;&nbsp;&nbsp;&nbsp;<b>Callbackparameters</b><br/>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>node</code> - resource object or string id of the
     * related resource, depending on the operation. For example, when a resource is created, the
     * resource itself is returned. In case of a delete operation, the id is returned
     * instead.<br/>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>mode</code> - the mode of the operation.
     * May be one of <code>OPERATION_GET</code>, <code>OPERATION_CREATE</code>,
     * <code>OPERATION_MODIFY</code>, or <code>OPERATION_DELETE</code>.<br/>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>statusCode</code> - the overall HTTP status code
     * of the operation.<br/>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>params</code> - the parameters
     * passed into the callback
     * @param {Object[]} parameters optional array of parameters to be
     * passed on to the callback function. May be <code>null</code>
     * @return {com.ibm.mashups.enabler.DeferredOperation} the deferred object
     */
    setOperationCallback: function(callback, parameters) {
    }
});

com.ibm.mashups.enabler.DeferredOperation.OPERATION_GET = "GET";
com.ibm.mashups.enabler.DeferredOperation.OPERATION_CREATE = "CREATE";
com.ibm.mashups.enabler.DeferredOperation.OPERATION_MODIFY = "MODIFY";
com.ibm.mashups.enabler.DeferredOperation.OPERATION_DELETE = "DELETE";

//</INTERFACE>

dojo.require( "com.ibm.mm.enabler.DeferredOperationImpl");
