/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.SubmittableForm");

//<INTERFACE>
dojo.require("com.ibm.mashups.enabler.Identifiable");

/**
 * An interface representing a submittable form. Submittable forms can be used
 * to import resources of models, which implement the SubmittableFormProvider
 * interface, for example spaces or templates. The provider of submittable forms
 * automatically set the necessary URL parameters, such as enctype, action and method.
 * To submit a submittable form, you invoke the submit()-method, which in turn
 * imports the resource using an appropriate xhr request.<br><br>
 * Example:<br>
 * <code>
 *   var form = spaceModel.getSubmittableImportForm(spaceId);<br>
 *   form.submit().start();<br>
 * </code>
 * @ibm-api
 * @ibm-module Base
 */
dojo.declare("com.ibm.mashups.enabler.SubmittableForm", com.ibm.mashups.enabler.Identifiable, {
    /**
     * Returns the URL this form is submitted to. Used to fill in the action attribute in the form.
     * @return {String} the URL this form is submitted to; never <code>null</code>
     */
    getURL: function(){
    },
    
    /**
     * Returns the HTTP method used to submit this form. Used to fill in the method attribute in the form.
     * @return {String} the method; never <code>null</code>
     */
    getMethod: function(){
    },
    
    /**
     * Submits the form
     * @return {com.ibm.mashups.enabler.Deferred} a deferred object used to start this operation.
     */
    submit: function(){
    }
});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.SubmittableFormImpl");
