/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.ac.AccessControlModelFactory");

dojo.require("com.ibm.mashups.enabler.layout.LayoutNode");
dojo.require("com.ibm.mashups.enabler.space.SpaceNode");
dojo.require("com.ibm.mashups.enabler.content.ContentNode");
dojo.require("com.ibm.mashups.enabler.ac.ResourceSpaceAccessControlModel");

//<INTERFACE>
/**
 * Interface for a access control model factory.
 * @ibm-api
 */
dojo.declare("com.ibm.mashups.enabler.ac.AccessControlModelFactory", null, {
    /**
     * Returns an ResourceAccessControlModel for the specified page. Note that
     * access control information is linked to the contents of a page. Thus,
     * the layout node of the respective page must be specified to obtain the
     * AccessControlModel of the page.
     * @param {com.ibm.mashups.enabler.layout.LayoutNode} resourceNode
     * page to obtain the AccessControlModel for.
     * @type ResourceAccessControlModel
     * 
     * @ibm-module CoreModel
     * @deprecated
     */
    getAccessControlModel: function(resourceNode){
    },
    
    /**
     * Returns an ResourceAccessControlModel for the specified page. Note that
     * access control information is linked to the contents of a page. Thus,
     * the content node of the respective page must be specified to obtain the
     * AccessControlModel of the page.
     * 
     * @param {com.ibm.mashups.enabler.content.ContentNode} resourceNode page to obtain the AccessControlModel for; must not be <code>null</code>.
     * @type ResourceAccessControlModel
     * 
     * @ibm-module CoreModel
     */
    getAccessControlModel: function(resourceNode){ // JSLINT-IGNORE: cannot change public API
    },
        
    /**
     * Returns an SpaceAccessControlModel for the specified space.
     * 
     * @param {com.ibm.mashups.enabler.space.SpaceNode} spaceNode space
     * to obtain the AccessControlModel for; must not be <code>null</code>.
     * 
     * @type SpaceAccessControlModel
     * 
     * @ibm-module SpaceModel
     */
    getAccessControlModel: function(spaceNode){ // JSLINT-IGNORE: cannot change public API
    },
    
    /**
     * Returns an ResourceSpaceAccessControlModel for the specified page within
     * the specified space. Note that access control information is linked to the
     * contents of a page. Thus, the layout node of the respective page must be
     * specified to obtain the AccessControlModel of the page.
     * 
     * @param {com.ibm.mashups.enabler.space.SpaceNode} spaceNode space containing
     * the specified page to obtain the AccessControlModel for.
     * @param {com.ibm.mashups.enabler.layout.LayoutNode} resourceNode page
     * to obtain the AccessControlModel for.
     * @type ResourceSpaceAccessControlModel
     * 
     * @ibm-module SpaceModel
     * @deprecated
     */
    getAccessControlModel: function(spaceNode, resourceNode){ // JSLINT-IGNORE: cannot change public API
    },
    
    /**
     * Returns an ResourceSpaceAccessControlModel for the specified page within
     * the specified space. Note that access control information is linked to the
     * contents of a page. Thus, the content node of the respective page must be
     * specified to obtain the AccessControlModel of the page.
     * 
     * @param {com.ibm.mashups.enabler.space.SpaceNode} spaceNode space containing
     * the specified page to obtain the AccessControlModel for; must not be <code>null</code>.
     * 
     * @param {com.ibm.mashups.enabler.content.ContentNode} resourceNode page
     * to obtain the AccessControlModel for; must not be <code>null</code>.
     * 
     * @type ResourceSpaceAccessControlModel
     * 
     * @ibm-module SpaceModel
     */
    getAccessControlModel: function(spaceNode, resourceNode){ // JSLINT-IGNORE: cannot change public API
    }
});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.ac.AccessControlModelFactoryImpl");
