/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.ac.operation.AllowedOperationsModel");

dojo.require("com.ibm.mashups.enabler.Deferred");
dojo.require("com.ibm.mashups.enabler.model.Model");
dojo.require("com.ibm.mashups.enabler.ac.operation.Operation");

//<INTERFACE>
/**
 * Interface for an allowed operations model.
 * This model allows to check for operations that the user may 
 * execute. E.g. it can be used by context menus to determine
 * the operations allowed for the current user.
 * Operations can be registered in the ibmConfig object
 * with "operations" or dynamically via the setOperations method.
 *
 * @ibm-module CoreModel
 */
dojo.declare("com.ibm.mashups.enabler.ac.operation.AllowedOperationsModel", [com.ibm.mashups.enabler.model.Model], {
    /**
     * Returns the requested operation.
     *
     * @param {String} operationName name of the operation. A few valid operations can be found here {@link com.ibm.mashups.enabler.ac.operation.Constants}.
     * @param {JSON} context JSON context passed to the operation.
     *               Each operation needs to define the format.
     * @type com.ibm.mashups.enabler.Deferred
     * @return the requested operation as a deferred object; <code>null</code>
     *         if no operation with the given name was found. The return value when executed through the
     * deferred object is a &nbsp; {@link com.ibm.mashups.enabler.ac.operation.Operation}.
     *
     * @ibm-api
     */
    getOperation: function(operationName, context){
    },
    /**
     * Define a new operation and a handler for that operation.
     *
     * @param {String} operationName name of the operation
     * @param {Object} callback the callback funtion used to verify the operation 
     * in the format of <code>Function(String operationName, JSON context, Boolean sync, Function finished)</code>. 
     * Must not be <code>null</code><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<b>Callback Parameters</b><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>operationName</code> - name of the operation to be verified. Never <code>null</code>.<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>context</code> - the JSON context passed to getOperation. Never <code>null</code>.<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>sync</code> - sync indicates if the deferred action is executed synchronously or asynchronously. Never<code>null</code>.<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>finished</code> - the function to be called once the operation has been loaded and the system can continue processing. Format is <code>Function finished({@link com.ibm.mashups.enabler.ac.operation.Operation} operation).</code>.<br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<b>Parameters for Function finished</b><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<code>operation</code> - the operation object. Must not be <code>null</code>.<br>
     * @type Boolean
     * @return <code>true</code> if the operation was added successfully, otherwise <code>false</code>
     *
     * @ibm-spi
     */
    setOperation: function(operationName, callback){
    }
});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.ac.operation.AllowedOperationsModelImpl");
