/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.logging.Logger");

//<INTERFACE>
dojo.require("com.ibm.mashups.enabler.logging.LogLevel" ); 
dojo.require("com.ibm.mashups.enabler.logging.LogHandler"); 

/**
* A Logger object is used to log messages for a specific system or application component. Loggers are 
* normally named, using a hierarchical dot-separated namespace. Logger names can be arbitrary strings, 
* but they should normally be based on the package name or class name of the logged component, such as <tt>com.ibm.mm.enabler</tt> or <tt>com.ibm.mm.enabler.services.ConfigService</tt>.
* <br/><br/>
* Logger objects may be obtained by calls on one of the getLogger factory methods. These will either create a new Logger or return a suitable existing Logger.
* <br/><br/>
* Logging messages will be forwarded to registered Handler objects, which can forward the messages to a variety of destinations, including consoles, files, OS logs, etc.
* <br/><br/>
* Each Logger keeps track of a &quot;parent&quot; Logger, which is its nearest existing ancestor in the Logger namespace. The default Enabler logging framework uses only one parent logger, the &quot;root Logger&quot;
* <br/><br/>
* On each logging call the Logger initially performs a cheap check of the request level (e.g. <tt>SEVERE</tt> or <tt>TRACE</tt>) against the effective global log level for the logger. If the request level is lower than the log level, the logging call returns immediately.
* <br/><br/>
* After passing this initial (cheap) test, the Logger will publish a the specified paramters to its output Handlers. By default, if the logger is not the root logger, it also publishes to it's parent's Handlers.
* <br/><br/>
* Most of the logger output methods take a &quot;message&quot; argument. This message argument may be either a raw value or a format string. During formatting, the format string will be filled in with the specified parameters. Otherwise the original message string is used. Typically the logger uses <tt>dojo.string.substitute</tt> style formatting to format parameters, so for example a format string &quot;<tt>${0} ${1}</tt>&quot; would format two parameters as strings.
* <br/><br/>
* A global JS object can be used to configure the loggers that are considered for tracing. <br />
* This object is named <code>traceConfig</code> and can be accessed through the &nbsp;{@link com.ibm.mashups.enabler.services.ConfigService ConfigService} or initialized by <tt>ConfigService.properties</tt><br/><br/>
* <pre>[
* "com.ibm.mashups.*",</br>
* "com.ibm.mm.*"
* ]</pre><br />Additional to the classes that should be logged the <code>isDebug</code> Flag must be set to <code>true</code>.
* 
* @since 2.0
* @ibm-module Base2
*/
dojo.declare("com.ibm.mashups.enabler.logging.Logger", null,
{
	/**
	* @private
	*/
	constructor: function() {
	},
	/**
	* Find or create a logger for a named subsystem. If a logger has already been created with the given name it is returned. Otherwise a new logger is created.
	* @ibm-api
	* @param {String} loggerName A name for the logger. This should be a dot-separated name and should normally be based on the package name or class name of the subsystem, such as com.ibm.mm.enabler or com.ibm.mm.enabler.services.ConfigService
	* @type {com.ibm.mashups.enabler.logging.Logger}
	* @return a suitable Logger 
	*/
	getLogger: function(loggerName) {
		return null;
	},
	/**
	* Adds a handler to the handler chain, so that it is capable of receiving events from the logging framework.
	* @ibm-spi
	* @param {com.ibm.mashups.enabler.logging.LogHandler} handler the LogHandler to subscribe to the specific logging events.
	* @type {void}
	*/
	addHandler: function(handler) {
	},
	/**
	* Removes a handler from the handler chain and unsubscribing it from the logging framework events.
	* @ibm-spi
	* @param {com.ibm.mashups.enabler.logging.LogHandler} handler the LogHandler to unsubscribe to the specific logging events.
	* @type {void}
	*/
	removeHandler: function(handler) {
	},
	/**
	* This is a convenience method that can be used to log entry to a method. A event with the message "ENTRY", log level <tt>TRACE</tt>, and the given methodName is published
	* @ibm-api
	* @param {String} methodName  the name of the method .
	* @param {Object[]} args  array of arguments that's passed into the method. Those arguments will be added to the entering comment in a comma separated way.
	* @type {void}
	*/ 	
	entering: function(methodName, args) {
	},
	/**
	* This is a convenience method that can be used to log returning of a method. A event with the message "RETURN", log level <tt>TRACE</tt>, and the given methodName is published. 
	* This method allows components to trace the exiting of the method.
	* @ibm-api
	* @param {String} methodName  the name of the method .
	* @param {Object[]} args  array of arguments that's passed into the method. Those arguments will be added to the exiting comment in a comma separated way.
	* @type {void}
	*/ 	
	exiting: function(methodName, args) {
	},
	/**
	* This method allows components to log an <tt>INFO</tt> level event.
	* @ibm-api
	* @param {String} methodName  the name of the method .
	* @param {String} message the message that you want to log.
	* @param {Object[]} args  array of arguments that's passed into the method. Those arguments will be filled into the wildcards in your message.
	* @type {void}
	*/ 	
	info: function(methodName, message, args) {
	},
	/**
	* This method allows components to log an <tt>WARNING</tt> level event.
	* @ibm-api
	* @param {String} methodName  the name of the method .
	* @param {String} message the message that you want to log.
	* @param {Object[]} args  array of arguments that's passed into the method. Those arguments will be filled into the wildcards in your message.
	* @type {void}
	*/ 	
	warning: function(methodName, message, args) {
	},
	/**
	* This method allows components to log an <tt>SEVERE</tt> level event.
	* @ibm-api
	* @param {String} methodName  the name of the method .
	* @param {String} message the message that you want to log.
	* @param {Object[]} args  array of arguments that's passed into the method. Those arguments will be filled into the wildcards in your message.
	* @type {void}
	*/ 	
	severe: function(methodName, message, args) {
	},
	/**
	* This method allows components to log an <tt>TRACE</tt> level event.
	* @ibm-api
	* @param {String} methodName  the name of the method .
	* @param {String} message the message that you want to log.
	* @param {Object[]} args  array of arguments that's passed into the method. Those arguments will be filled into the wildcards in your message.
	* @type {void}
	*/ 	
	trace: function(methodName, message, args) {
	},
	/**
	* This method allows components to log a logging event for the specified &nbsp;{@link com.ibm.mashups.enabler.logging.LogLevel LogLevel}
	* @ibm-api
	* @param {int} logLevel the &nbsp;{@link com.ibm.mashups.enabler.logging.LogLevel LogLevel} to use for logging.
	* @param {String} methodName  the name of the method.
	* @param {String} message the message that you want to log.
	* @param {Object[]} args  array of arguments that's passed into the method. Those arguments will be filled into the wildcards in your message.
	* @type {void}
	*/ 	
	log: function(logLevel, methodName, message, args) {
	},
	/**
	* Check if a message of the given level would actually be logged by this logger.
	* @ibm-api
	* @param {int} logLevel the &nbsp;{@link com.ibm.mashups.enabler.logging.LogLevel LogLevel} to check
	* @type {boolean}
	* @return <code>true</code> if the given message level is currently being logged.
	*/
	isLoggable: function(logLevel) {
		return false;
	}
});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.logging.LoggerImpl");
