/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.model.NavigationModel");

dojo.require("com.ibm.mashups.enabler.Deferred");
dojo.require("com.ibm.mashups.enabler.DeferredOperation");
dojo.require("com.ibm.mashups.enabler.TreeModelController");
dojo.require("com.ibm.mashups.enabler.Discardable");
dojo.require("com.ibm.mashups.enabler.Invalidatable");
dojo.require("com.ibm.mashups.enabler.Primeable");
dojo.require("com.ibm.mashups.enabler.model.SelectionLocator");
dojo.require("com.ibm.mashups.enabler.navigation.Constants");
dojo.require("com.ibm.mashups.enabler.strategy.ListLoadAheadStrategy");
dojo.require("com.ibm.mashups.enabler.strategy.HiddenMetaDataLoadingStrategy");
dojo.require("com.ibm.mashups.enabler.model.LayoutModel");
//<INTERFACE>
/**
 * Interface for a navigation model. This tree model describes the topology in
 * which the navigation is structured. Elements in this model are navigation
 * elements, such as navigation nodes or labels.<br>
 * <br>
 * The navigation model supports the following strategies:
 * <ul>
 * <li>{@link com.ibm.mashups.enabler.strategy.ListLoadAheadStrategy ListLoadAheadStrategy}</li>
 * <li>{@link com.ibm.mashups.enabler.strategy.HiddenMetaDataLoadingStrategy HiddenMetaDataLoadingStrategy}</li>
 * </ul>
 * @ibm-module CoreModel
 */
dojo.declare("com.ibm.mashups.enabler.model.NavigationModel", [com.ibm.mashups.enabler.TreeModelController, com.ibm.mashups.enabler.model.SelectionLocator, com.ibm.mashups.enabler.Discardable, com.ibm.mashups.enabler.Invalidatable, com.ibm.mashups.enabler.Primeable], {

    /**
     * Sets priming data for the navigation model in Json format:<br>
     * &nbsp;&nbsp;<tt>PRIMED_NODE = {</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>id: ID,</tt><br> 
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>title: TITLE,</tt><br> 
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>locale: LOCALE,</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>theme: THEME</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>(, metadata: METADATA)?</tt><br> 
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>(, type: TYPE)?</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>(, roles: ROLES)?</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>(, isPrivate: true &#124; false)?</tt><br>
     * &nbsp;&nbsp;&nbsp;&nbsp;<tt>(, children: [(END, )? PRIMED_NODE(, PRIMED_NODE)&#42; (, END)?])?</tt><br>
     * &nbsp;&nbsp;<tt>}</tt><br>
     * <br>
     * Where: <br>
     * <ul>
     * <li><tt>PRIMED_NODE</tt> is priming data for a navigation node</li>
     * <li><tt>ID</tt> is the id of the navigation node</li>
     * <li><tt>TITLE</tt> is the title of the navigation node</li>
     * <li><tt>TYPE</tt> is the type of the navigation node, i.e. one of the following: 
     * <ul>
     * <li><tt>page</tt></li>
     * <li><tt>label</tt></li>
     * <li><tt>url</tt></li>
     * </ul>
     * optional, defaults to <tt>"page"</tt>. 
     * <li><tt>LOCALE</tt> is the locale of the navigation node</li>
     * <li><tt>THEME</tt> is the theme id of the navigation node</li>
     * <li><tt>METADATA</tt> is an object containing an arbitrary number of key-value pairs</li>
     * <li><tt>ROLES</tt> is an array containing zero or more of the following roles:</li>
     * <ul>
     * <li><tt>user</tt></li>
     * <li><tt>privilegedUser</tt></li>
     * <li><tt>editor</tt></li>
     * <li><tt>manager</tt></li>
     * <li><tt>admin</tt></li>
     * </ul>
     * <li><tt>END</tt> is an empty object</li>
     * </ul>
     * <br>
     * Additionally, the following rules apply:
     * <ul>
     * <li>the top-level node must be the root node of the topology</li>
     * <li>When END occurs as the last element, it indicates that no more children are present, i.e. that all existing children are primed. If the last element is not the END marker, then there might be more (unprimed) children.</li>
     * <li>When END occurs as the first element, it indicates that any primed children are not necessarily primed in order and don't start at the first index. This effectively allows parent relationships to be primed
     * but any calls to getChildren of this node will result in an unprimed request for all the children.</li>
     * <li>specifying an empty array for children is the same as not specifying the children property at all</li>
     * </ul>
     * @param {Object} data data to prime the navigation model with; must not be <code>null</code>.
     * @type void
     * @ibm-spi
     */
    setPrimingData: function(data) {
    },
    
    /**
     * Indicates if the specified page has an attached layout model.
     *
     * @param {com.ibm.mashups.enabler.navigation.NavigationNode} page page object or page uri (without any scope)
     * for which to check if it has a layout model. Must not be <code>null</code>.
     * @return {Boolean} <tt>true</tt> if the specified node has a layout model, <tt>false</tt> otherwise
     * @ibm-api
     */
    hasLayoutModel: function(page) {
    },
    
    /**
     * Returns the layout model for the given page.
     *
     * @param {com.ibm.mashups.enabler.navigation.NavigationNode} page the page object or the uri of the page for
     * which to return its model. The page must be part
     * of this model. Must not be <code>null</code>.
     * @return {com.ibm.mashups.enabler.model.LayoutModel} a layout model or <code>null</code> if none exists.
     * @ibm-api
     */
    getLayoutModel: function(page) {
    },
    
    /**
     * Returns a Deferred object to obtain a special node of the model defining the root
     * of all pages, which are shared with a user. May be <code>null</code> if the
     * navigation tree is empty
     * @type com.ibm.mashups.enabler.Deferred(Object)
     * @return a deferred object used to start this operation. The return value
     * when executed through the deferred object is the shared root object of the tree model
     * @ibm-api
     */
    getSharedRoot: function() {
    },
    
    /**
     * Confirms whether exporting the page is possible.
     * @param {com.ibm.mashups.enabler.navigation.NavigationNode} page page or page URI (without any scope).
     *                      Must not be <code>null</code>
     * @return {Boolean} <code>true</code> if the page can be exported, <code>false</code> otherwise.
     * @ibm-api
     */
    confirmExport: function(page) {
    },
    
    /**
     * Creates a new navigation entity. You may create navigation nodes, labels, as well as URLs.
     * Note that the entity will not appear in the model unless it is inserted using the
     * <code>insert</code> method.
     *
     * @see com.ibm.mashups.enabler.navigation.NavigationNode
     * @see com.ibm.mashups.enabler.navigation.NavigationLabel
     * @see com.ibm.mashups.enabler.navigation.NavigationURL
     *
     * @param {JSON} context context of predefined information used for the creation of
     * the navigation entity. Must not be <code>null</code>. Accepted names are:<br>
     * &nbsp;&nbsp;<b><code>type</code></b> - type of navigation entity to create as defined
     * in &nbsp; {@link com.ibm.mashups.enabler.navigation.Constants Constants}; must be one
     * of be one of the following:<br>
     * &nbsp;&nbsp;&nbsp;NAVIGATION_PAGE<br>
     * &nbsp;&nbsp;&nbsp;NAVIGATION_LABEL<br>
     * &nbsp;&nbsp;&nbsp;NAVIGATION_URL<br>
     * &nbsp;&nbsp;In case type equals NAVIGATION_PAGE, you may specify the following:<br>
     * &nbsp;&nbsp;<b><code>template</code></b> - creates a new navigation node based on
     * the specified com.ibm.mashups.enabler.navigation.NavigationNode<br>
     * &nbsp;&nbsp;<b>Reserved Keywords:</b> <code>private</code>
     *
     * @return {Object} the created navigation entity
     *
     * @see com.ibm.mashups.enabler.navigation.Constants
     * @ibm-api
     */
    create: function(context) {
    },
    
    /**
     * Commits the modifications applied to this model and all dependent models.<br>
     * @return {DeferredOperation} a deferred object used to start this operation.
     * The return value when executed through the deferred object is <code>null</null>
     * @ibm-api
     */
    commit: function() {
    }
});
//</INTERFACE>

dojo.require("com.ibm.mashups.enabler.navigation.NavigationNode");
dojo.require("com.ibm.mashups.enabler.navigation.NavigationLabel");
dojo.require("com.ibm.mashups.enabler.navigation.NavigationURL");

dojo.require("com.ibm.mm.enabler.model.NavigationModelImpl");
