/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.model.space.SpaceExtension");

dojo.require("com.ibm.mashups.enabler.model.space.SpaceExtensionResult");
dojo.require("com.ibm.mashups.enabler.model.SpaceExtensionModel");
dojo.require("com.ibm.mashups.enabler.Locator");
dojo.require("com.ibm.mashups.enabler.ListModelController"); 

/**
 *
 * Interface SpaceExtension for space life cycle events.
 * @ibm-api
 * @ibm-module SpaceModel
 */
dojo.declare("com.ibm.mashups.enabler.model.space.SpaceExtension", null, {

    /**
     * This method is called before space is created in business space.
     *
     * spaceId: String, Id of the space
     * spaceName: String, name of the space
     * spaceDescription: String, description of the space
     * optionalInfo: this is a field reserved for future.
     *
     * return: SpaceExtensionResult or no return.
     *         No return means "notification has been delivered successfully and accepted".
     */
    onSpaceCreate: function(spaceId, spaceName, spaceDescription, optionalInfo){
        // alert("SpaceExtension.onSpaceCreate");
    },
    
    /**
     * This method is called before space is copied in business space.
     *
     * sourceSpaceId: String, Id of the source space
     * targetSpaceId: String, Id of the target space
     * targetSpaceName: String, name of the target space
     * targetDescription: String, description of the target space
     * optionalInfo: this is a field reserved for future.
     *
     * return: SpaceExtensionResult or no return.
     *         No return means "notification has been delivered successfully and accepted".
     */
    onSpaceCopy: function(sourceSpaceId, targetSpaceId, targetSpaceName, targetDescription, optionalInfo){
        // alert("SpaceExtension.onSpaceCopy");
    },
    
    /**
     * This method is called before space is updated in business space.
     *
     * spaceId: String, Id of the space
     * spaceData: JSON object, the set of space data that's going to be updated.
     * optionalInfo: this is a field reserved for future.
     *
     * return: SpaceExtensionResult or no return.
     *         No return means "notification has been delivered successfully and accepted".
     */
    onSpaceUpdate: function(spaceId, spaceData, optionalInfo){
        // alert("SpaceExtension.onSpaceUpdate");
    },
    
    /**
     * This method is called before space is deleted in business space.
     *
     * spaceId: String, Id of the space
     * optionalInfo: this is a field reserved for future.
     *
     * return: SpaceExtensionResult or no return.
     *         No return means "notification has been delivered successfully and accepted".
     */
    onSpaceDelete: function(spaceId, optionalInfo){
        // alert("SpaceExtension.onSpaceDelete");
    },
    
    /**
     * This method is used to check if the specified space can be exported.
     *
     * spaceId: String, Id of the space
     * optionalInfo: this is a field reserved for future.
     *
     * return: SpaceExtensionResult or no return.
     *         No return means that the space can be exported.
     */
    canExportSpace: function(spaceId, optionalInfo){
        // alert("SpaceExtension.canExportSpace");
    },
    
    /**
     * This method is used to check if the specified space can be copied.
     *
     * spaceId: String, Id of the space
     * optionalInfo: this is a field reserved for future.
     *
     * return: SpaceExtensionResult or no return.
     *         No return means that the space can be copied.
     */
    canCopySpace: function(spaceId, optionalInfo){
        // alert("SpaceExtension.canCopySpace");
    },
    
    /**
     * This method is used to check if the specified space can be deleted.
     *
     * spaceId: String, Id of the space
     * optionalInfo: this is a field reserved for future.
     *
     * return: SpaceExtensionResult or no return.
     *         No return means that the space can be deleted.
     */
    canDeleteSpace: function(spaceId, optionalInfo){
        // alert("SpaceExtension.prototype.canDeleteSpace");
    }    
});
