/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.strategy.TreeLoadAheadStrategy");

dojo.require("com.ibm.mashups.enabler.strategy.Strategy");

/**
 * Interface that defines a load ahead strategy for loading elements wihin a
 * tree hierarchy. When applied to a tree model it will load the given number
 * of elements at a time from the backend.<br>
 * Example; A TreeLoadAheadStrategy with parentLevel = 2 and childrenLevel = 2 will<br>
 * <ul><li>load the parent as well as all the parents of the parent when calling
 * getParent on a given node and</li>
 * <li>load the children as well as all the children of the child when calling
 * getChildren on a given node.</li></ul>
 * @ibm-api
 * @ibm-module Base
 */
dojo.declare("com.ibm.mashups.enabler.strategy.TreeLoadAheadStrategy", com.ibm.mashups.enabler.strategy.Strategy, {
    /**
     * @param {int} parentLevel number of parent levels to be loaded ahead from
     * the backend. must not be <code>null</code> or less than one.
     * @param {int} childrenLevel number of children levels to be loaded ahead
     * from the backend. must not be <code>null</code> or less than one.
     */
    constructor: function(parentLevel, childrenLevel){
        this.parentLevel = parentLevel;
        this.childrenLevel = childrenLevel;
    },
    
    /**
     * Returns the number of children levels in the hierarchy to load ahead
     * @return {int} number of children levels to load ahead
     */
    getChildrenLevel: function(){
        return this.childrenLevel;
    },
    
    /**
     * Returns the number of parent levels in the hierarchy to load ahead
     * @return {int} number of parent levels to load ahead
     */
    getParentLevel: function(){
        return this.parentLevel;
    }
});
