/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.widget.ModifiablePreferences");

dojo.require("com.ibm.mashups.enabler.widget.Preferences");

/**
 * An interface representing modifiable preferences. It can be obtained through an&nbsp; {@link com.ibm.mashups.enabler.widget.PreferencesProvider PreferencesProvider}.
 * @since 2.4
 *
 * @ibm-api
 * @ibm-module CoreModel
 */
dojo.declare("com.ibm.mashups.enabler.widget.ModifiablePreferences", com.ibm.mashups.enabler.widget.Preferences, {
    /**
     * Indicates if the preference identified with the specified name may be removed. 
     * @param {String} name name of preference. Must not be <tt>null</tt>
     * @return {boolean} <code>true</code> in case the preference may be removed, <code>false</code> otherwise
     */
    confirmRemove: function(name) {
    },
	
    /**
     * Indicates if the value for the preference identified by the specified name may be set.
     * @param {String} name name of preference. Must not be <tt>null</tt>
     * @param {String} value preference value. Must not be <tt>null</tt>
     * @return {boolean} <code>true</code> in case the preference may be set, <code>false</code> otherwise
     */
    confirmSetValue: function(name, value) {
    },
    /**
     * Indicates if the values for the preference identified by the specified name may be set.
     * @param {String} name name of preference. Must not be <tt>null</tt>
     * @param {String[]} values preference values. Must not be <tt>null</tt>
     * @return {boolean} <code>true</code> in case the preference may be set, <code>false</code> otherwise
     */
    confirmSetValues: function(name, values) {
    },
	
    /**
     * Indicates if the readOnly parameter of the&nbsp; {@link #setValue(String, String, boolean) setValue} method
     *  is evaluated by the remote system.
     * @param {String} name name of preference. Must not be <tt>null</tt>
     * @return {boolean} <code>true</code> in case the readOnly parameter is evaluated, <code>false</code> otherwise.
     */
    confirmSetReadOnly: function(name) {
    },
	
    /**
     * Sets the value for the preference identified by the specified name. The value has to be of type String. 
     * If the name does not exist a new preference is created with the given name, value and read-only to <code>false</false>.
     * @param {String} name name of preference to set the value for. Must not be <tt>null</tt>
     * @param {String} value preference value to set. Must not be <tt>null</tt>
     * @return {boolean} returns <tt>true</tt> in case the setting of the value was successful, <tt>false</tt> otherwise.
     */
    setValue: function(name, value){ // JSLINT-IGNORE: cannot change public API
    },
	
    /**
     * Sets the value for the preference identified by the specified name. The value has to be of type String. 
     * If the name does not exist a new preference is created with the given name, value.
     * @param {String} name name of preference to set the value for. Must not be <tt>null</tt>
     * @param {String} value preference value to set. Must not be <tt>null</tt>
     * @param {boolean} readOnly <code>true</code> if a <b>new</b> created preference should be read-only. <code>false</code> otherwise. default: <code>false</code>
     * @return {boolean} returns <tt>true</tt> in case the setting of the value was successful, <tt>false</tt> otherwise.
     */
    setValue: function(name, value, readOnly) { // JSLINT-IGNORE: cannot change public API
    },
    /**
     * Sets the values for the preference identified by the specified name. The values have to be of type String. 
     * If the name does not exist a new preference is created with the given name, value.
     * @param {String} name name of preference to set the value for. Must not be <tt>null</tt>
     * @param {String[]} values preference values to set. Must not be <tt>null</tt>
     * @return {boolean} returns <tt>true</tt> in case the setting of the values was successful, <tt>false</tt> otherwise.
     */
    setValues: function(name, values) { // JSLINT-IGNORE: cannot change public API
    },
    /**
     * Sets the values for the preference identified by the specified name. The values have to be of type String. 
     * If the name does not exist a new preference is created with the given name, value.
     * @param {String} name name of preference to set the value for. Must not be <tt>null</tt>
     * @param {String[]} values preference values to set. Must not be <tt>null</tt>
     * @param {boolean} readOnly <code>true</code> if a <b>new</b> created preference should be read-only. <code>false</code> otherwise. default: <code>false</code>
     * @return {boolean} returns <tt>true</tt> in case the setting of the values was successful, <tt>false</tt> otherwise.
     */
    setValues: function(name, values, readOnly) { // JSLINT-IGNORE: cannot change public API
    },
    /**
     * Removes the preference identified with the specified name. If read-only is specified, the preference will not be removed.
     * <i>Note: if this object is hierachical, then the remove method will only remove any value on the top layer (if available).</i>
     * @param {String} name name of preference to remove. Must not be <tt>null</tt>
     * @see com.ibm.mashups.enabler.widget.WidgetModel#getHierachicalPreferences(PreferenceProvider) 
     * @return {boolean} returns <tt>true</tt> in case the removing of the value was successful, <tt>false</tt> otherwise.
     */
    remove: function(name) {
    }
});

/**
 * @private
 */
com.ibm.mashups.enabler.widget.ModifiablePreferences.TOPIC_BASE = "/"+("com.ibm.mashups.enabler.widget.ModifiablePreferences".replace(/\./ig,'/'))+"/";
/**
 * @private
 */
com.ibm.mashups.enabler.widget.ModifiablePreferences.TOPIC_PREFERENCES_SET    = com.ibm.mashups.enabler.widget.ModifiablePreferences.TOPIC_BASE + "set";
/**
 * @private
 */
com.ibm.mashups.enabler.widget.ModifiablePreferences.TOPIC_PREFERENCES_REMOVE = com.ibm.mashups.enabler.widget.ModifiablePreferences.TOPIC_BASE + "remove";
