/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.widget.WidgetModel");

//<INTERFACE>
dojo.require("com.ibm.mashups.enabler.Identifiable");
dojo.require("com.ibm.mashups.enabler.Locator");
dojo.require("com.ibm.mashups.enabler.Commitable");
dojo.require("com.ibm.mashups.enabler.Discardable");
dojo.require("com.ibm.mashups.enabler.model.Model");
dojo.require("com.ibm.mashups.enabler.widget.WidgetWindow");
dojo.require("com.ibm.mashups.enabler.widget.WidgetDefinition");
dojo.require("com.ibm.mashups.enabler.widget.WidgetInstance");
dojo.require("com.ibm.mashups.enabler.layout.LayoutControl");

/**
 * This interface provides a model for widgets. It exposes widget definitions,
 * instances, and windows. You may create widget instances based on definitions
 * and remove widget instances.<br>
 * <br>
 * The widget model supports the following strategies:
 * <ul>
 * <li>{@link com.ibm.mashups.enabler.strategy.HiddenMetaDataLoadingStrategy HiddenMetaDataLoadingStrategy}</li>
 * </ul>
 *
 * @since 2.4
 *
 * @ibm-api
 * @ibm-module CoreModel
 */
dojo.declare("com.ibm.mashups.enabler.widget.WidgetModel", [com.ibm.mashups.enabler.Commitable,
                                                           com.ibm.mashups.enabler.model.Model,
                                                           com.ibm.mashups.enabler.Locator,
														   com.ibm.mashups.enabler.Discardable], {
    /**
     * Returns the widget definition specified with the id.
     *
     * @param {com.ibm.mashups.enabler.Identifiable} id of the widget definition
     * @return {com.ibm.mashups.enabler.Deferred} a deferred object used to start this operation,
     * never <code>null</code>. The return value when executed through the deferred
     * object is a&nbsp; {@link com.ibm.mashups.enabler.widget.WidgetDefinition WidgetDefinition} for the given&nbsp; {@link Identifiable Identifiable} or <tt>null</tt> if no
     * widget definition is found.
     */
    find: function(id){
    },
    
    /**
     * Returns the widget definition specified with the widget window
     * @param {com.ibm.mashups.enabler.widget.WidgetWindow} window the widget window
     * @return {com.ibm.mashups.enabler.Deferred} a deferred object used to start this operation,
     * never <code>null</code>. The return value when executed through the deferred
     * object is a&nbsp; {@link com.ibm.mashups.enabler.widget.WidgetDefinition WidgetDefinition} for the given&nbsp; {@link com.ibm.mashups.enabler.widget.WidgetWindow WidgetWindow} or <tt>null</tt> if no
     * widget definition is found.
     */
    getWidgetDefinitionByWindow: function(window){
    },
    
    /**
     * Returns the widget definition specified with the widget instance
     * @param {com.ibm.mashups.enabler.widget.WidgetInstance} instance the widget instance
     * @return {com.ibm.mashups.enabler.Deferred} a deferred object used to start this operation,
     * never <code>null</code>. The return value when executed through the deferred
     * object is a&nbsp; {@link com.ibm.mashups.enabler.widget.WidgetDefinition WidgetDefinition} for the given&nbsp; {@link com.ibm.mashups.enabler.widget.WidgetInstance WidgetInstance} or <tt>null</tt> if no
     * widget definition is found.
     */
    getWidgetDefinitionByInstance: function(instance){
    },
    
    /**
     * Returns the widget window of the specified layout control.
     * @param {com.ibm.mashups.enabler.layout.LayoutControl} control the layout control
     * @return {com.ibm.mashups.enabler.Deferred} a deferred object used to start this operation,
     * never <code>null</code>. The return value when executed through the deferred
     * object is a&nbsp; {@link WidgetWindow WidgetWindow} for the given&nbsp; {@link LayoutControl LayoutControl} or <tt>null</tt> if no
     * widget window is found.
     */
    getWidgetWindow: function(control){
    },
    
    /**
     * Returns the widget instance of the specified widget window.
     * @param {com.ibm.mashups.enabler.widget.WidgetWindow} window the widget window
     * @return {com.ibm.mashups.enabler.Deferred} a deferred object used to start this operation,
     * never <code>null</code>. The return value when executed through the deferred
     * object is a&nbsp; {@link com.ibm.mashups.enabler.widget.WidgetInstance WidgetInstance} for the given&nbsp; {@link com.ibm.mashups.enabler.widget.WidgetWindow WidgetWindow} or <tt>null</tt> if no
     * widget instance is found.
     */
    getWidgetInstance: function(window){
    },
    /**
     * Gets hierarchical preferences of the specified&nbsp; {@link PreferenceProvider PreferenceProvider} down to the levels. 
     * This means, that the preferences of each level (definition, instance and window) will be aggregated, depending on which preference provider you provided as argument.
     * @param {com.ibm.mashups.enabler.widget.PreferencesProvider} preferenceProvider the preference provider from which to aggregate preferences down.
     * @return {com.ibm.mashups.enabler.Deferred} returns an&nbspM {@link ModifiablePreferences ModifiablePreferences} object, that represents the aggregated preferences down to the lowest level, starting on the preference level of the given&nbsp; {@link PreferenceProvider PreferenceProvider}
     */
    getHierarchicalPreferences: function(preferenceProvider) {
        
    },
    /**
     * Gets the <i>hierarchical</i>&nbsp; {@link EventProvider EventProvider} for the specified&nbsp; {@link EventProvider EventProvider} down to the levels. 
     * This means, that the events of each level (definition, instance and window) will be aggregated, depending on which event provider you provided as argument and then be accessible through the retuned eventprovider.
     * @param {com.ibm.mashups.enabler.widget.EventProvider} eventProvider the event provider from which to aggregate events down.
     * @return {com.ibm.mashups.enabler.Deferred} returns an&nbsp; {@link ModifiableEventProvider ModifiableEventProvider} providing the aggregated events down to the lowest level, starting on the event level of the given&nbsp; {@link EventProvider EventProvider}
     */
    getHierarchicalEventProvider: function(eventProvider) {
        
    }
});
//</INTERFACE>

dojo.require("com.ibm.mm.enabler.widget.WidgetModelImpl");
