/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.iwidget.itemset.ItemSet");

/**
 * Interface to a simple abstraction of a datamodel. This provides a base from which more sofisticated data models can be built.
 * @ibm-api
 * @ibm-module iWidget2
 */
dojo.declare("com.ibm.mashups.iwidget.itemset.ItemSet", null, {
    /**
     @private
     */
    constructor: function() {
    },
    /**
     This method sets an item within the ItemSet, creates or replaces an existing entry as needed.
     Since only one value is allowed for any one name/locale combination, the supplied value replaces any existing value for the supplied name/locale.
	 When successful, this method MUST return a handle to the ItemSet while on failure it must return null.
     @param{String}itemName name of the item. Must never be <code>null</code>.
     @param{Object}value value of the item. Must never be <code>null</code>.
     @param{String}locale specified locale. Must never be <code>null</code>.
     @return{ItemSet} return an handle of ItemSet upon successful, <code>null</code> upon failure.
     */
    setLocalizedItemValue: function( /*String*/itemName, /*Object*/ value,/*String*/ locale) { 
        return this;
    },
    /**
     This method sets an item within the ItemSet, creates or replaces an existing entry as needed.
     To append a value to any existing item, suggest to get the current value of this item and append
     the new value to the list and supply the result to this method.
     Marking an item as ReadOnly indicates to the iContext that while this item maybe shared with other components
     on the page, the access of those components should not include changing or removing item.
     @param{String}itemName name of the item. Must never be <code>null</code>.
     @param{Object}value value of the item. Must never be <code>null</code>.
     @param{Boolean}readOnly optional Boolean attribute to indicate this item is readOnly or not.Default value is false if this parameter is not provided.
     @return{ItemSet} return an handle of ItemSet upon successful, <code>null</code> upon failure.
     @deprecated please use setItemValue(itemName,value) readOnly is always false
     */
    setItemValue: function( /*String*/itemName, /*Object*/ value,/*boolean*/ readOnly) {// JSLINT-IGNORE: in Java functions with the same name but different signatures are allowed - this is only used for generating JavaDoc
        return this;
    },	
	/**
     This method sets a nonlocalized value of an item within the ItemSet, creates or replaces an existing entry as needed.
     @param{String}itemName name of the item. Must never be <code>null</code>.
     @param{Object}value value of the item. Must never be <code>null</code>.
     @return{ItemSet} return an handle of ItemSet upon successful, <code>null</code> upon failure.
     */
    setItemValue: function( /*String*/itemName, /*Object*/ value) {// JSLINT-IGNORE: in Java functions with the same name but different signatures are allowed - this is only used for generating JavaDoc
        return this;
    },	
	/**
     This method returns the value for the named item in the specified locale. On failure this method MUST return null.
     @param{String}itemName name of the item. Must never be <code>null</code>.
     @param{String}locale specified locale. Must never be <code>null</code>.
     @return{Object} return value of the item, <code>null</code> upon failure.
     */
    getLocalizedItemValue: function( /*String*/itemName,/*String*/locale) {
        return null;
    },
    /**
     This method returns the nonlocalized value for the named item from the set.
     @param{String}itemName name of the item. Must never be <code>null</code>.
     @return{ItemSet} return the named item for the set, <code>null</code> upon failure.
     */
    getItemValue: function( /*String*/itemName) {
        return null;
    },
    /**
     This method returns an array of Strings, providing the name of each item.
     @return{String[]}  return an array of items names and return <code>null</code> if the set contains no item
     */
    getAllNames: function() {
        return null;
    },
    /**
     Removes the named item from the set.
     @param{String}itemName name of the item that needs to be removed. Must never be <code>null</code>.
     @return{ItemSet} return the handle to the ItemSet upon successful, <code>null</code> upon failure.
     */
    removeItem: function(/*String*/itemName) {
        return null;
    },
	 /**
     Removes the non localized value of the item from the set.
     @param{String}itemName name of the item that needs to be removed. Must never be <code>null</code>.
     @return{ItemSet} return the handle to the ItemSet upon successful, <code>null</code> upon failure.
     */
    removeItemValue: function(/*String*/itemName) {
        return null;
    },
	 /**
     Removes the  value of the item from the set for a specified locale.
     @param{String}itemName name of the item that needs to be removed. Must never be <code>null</code>.
     @param{String}locale a specified locale. Must never be <code>null</code>.
     @return{ItemSet} return the handle to the ItemSet upon successful, <code>null</code> upon failure.
     */
    removeLocalizedItemValue: function(/*String*/itemName,/*String*/locale) {
        return null;
    },
   /**
     The method returns an array of strings, each providing a locale where a value is defined. The empty string"" is
     returned for a value without a locale. if the set does not contain the names item, this method must return null.
     @param{String}itemName name of the item.  Must never be <code>null</code>.
     @return{String[]} return an array each providing  a locale where a value is defined.
     */
    getLocalesWithValues: function(/*String*/itemName) {
        return null;
    },
    /**
     This method returns a new ItemSet which is a duplicate of the current ItemSet.
     @return{ItemSet}  return a new ItemSet which contains all the data item in the current ItemSet
     @deprecated not used
     */
    clone: function() {
        return null;
    },
    /**
     This method returns a Boolean indicating whether or not the item specified by the supplied name can be modified by the user.
     @param{String}itemName name of the required Item. Must never be <code>null</code>.
     @return{Boolean} return a Boolean indicating whether or not the item specified by the supplied name can be modified by the user. Never <code>null</code>.
     @deprecated always return false
     */
    isReadOnly: function(/*String*/itemName) {
        return false;
    },
    /**
     As a limitation in Lotus Mashups, this method returns <code>null</code>.
     @return{Object} return As a limitation in Lotus Mashups, this method returns <code>null</code>.
     @deprecated not used
     */
    getItemSetDescription: function() {
        return null;
    },
		/**
     This function adds listener to this ShareableItemSet. So it will gets notified when this ShareableItemSet is updated.
     @param{Function}listener js function that should already be properly scoped. Must never be <code>null</code>.
     @return{String} return listener id if listener is registered successfully, return null if it's not.
     @deprecated not used
     */
    addListener: function(/*Function*/listener) {
        return null;
    },
    /**
     This function removes the  listener from this ShareableItemSet.
     @param{String}listenerId  listener id that's returned by the system when listener is added. Must never be <code>null</code>.
     @return{Boolean} return true if listener is removed successfully.
     @deprecated not used
     */
    removeListener: function(/*String*/listenerId) {
        return true;
    } //return true if listener is removed successfully
});
